==> bitcream-smartsignage-custom-v0.4-263a7a.zip: common/models/Text.php <==
<?php

namespace bitcream\smartsignage\custom\common\models;

use Yii;
use bitcream\smartsignage\custom\common\behaviors\StatusBehaviors;
use bitcream\smartsignage\custom\common\behaviors\CreateUpdateBehaviors;
use yii2tech\ar\softdelete\SoftDeleteBehavior;
use bitcream\smartsignage\custom\common\behaviors\SendNotification;

/**
 * This is the model class for table "{{%image}}".
 *
 */
class Text extends base\Text
{
    public function behaviors()
    {
        return array_merge(parent::behaviors(), [
            'status' => [
                'class' => StatusBehaviors::className(),
            ],
            'create-update' => [
                'class' => CreateUpdateBehaviors::className(),
            ],
            'softDeleteBehavior' => [
                'class' => SoftDeleteBehavior::className(),
                'softDeleteAttributeValues' => [
                    'status' => 0
                ],
                'replaceRegularDelete' => true // mutate native `delete()` method
            ],
            'send-notification' => [
                'class' => SendNotification::className(),
            ],
       ]);
    }

    public function fields(){
        return [
            'content_type' => "contentType",
            'text',
            'style'=> function ($model){
                return [
                    'background_color' => $this->background_color,
                    'text_color' => $this->text_color,
                    'text_size' => $this->text_size,
                    'font_family' => $this->font_family,
                    'font_weight' => $this->font_weight,
                ];
            },
            'animation' => function ($model){
                return [
                    'speed' => $this->speed,
                ];
            },
        ];
    }

    public static function getContentType()
    {
        return "text";
    }
}

==> bitcream-smartsignage-custom-v0.6-16ba45.zip: common/models/Text.php <==
<?php

namespace bitcream\smartsignage\custom\common\models;

use Yii;
use bitcream\smartsignage\custom\common\behaviors\StatusBehaviors;
use bitcream\smartsignage\custom\common\behaviors\CreateUpdateBehaviors;
use yii2tech\ar\softdelete\SoftDeleteBehavior;
use bitcream\smartsignage\custom\common\behaviors\SendNotification;
use yii\helpers\ArrayHelper;


/**
 * This is the model class for table "{{%image}}".
 *
 */
class Text extends base\Text
{
    public function behaviors()
    {
        return array_merge(parent::behaviors(), [
            'status' => [
                'class' => StatusBehaviors::className(),
            ],
            'create-update' => [
                'class' => CreateUpdateBehaviors::className(),
            ],
            'softDeleteBehavior' => [
                'class' => SoftDeleteBehavior::className(),
                'softDeleteAttributeValues' => [
                    'status' => 0
                ],
                'replaceRegularDelete' => true // mutate native `delete()` method
            ],
            'send-notification' => [
                'class' => SendNotification::className(),
            ],
       ]);
    }

    public function fields(){
        return [
            'content_type' => "contentType",
            'text',
            'style'=> function ($model){
                return [
                    'background_color' => $this->background_color,
                    'text_color' => $this->text_color,
                    'text_size' => $this->text_size,
                    'font_family' => $this->font_family,
                    'font_weight' => $this->font_weight,
                ];
            },
            'animation' => function ($model){
                return [
                    'speed' => $this->speed,
                ];
            },
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function rules()
    {
        return ArrayHelper::merge(parent::rules(), [
            // each category_id must exist in category table (*1)
            [['text', 'speed', 'background_color', 'text_color', 'text_size', 'font_family', 'font_weight'], 'required'],

        ]);
    }

    public static function getContentType()
    {
        return "text";
    }
}
